==> haskell-aeson-1.5.6.0-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson
version:              1.5.6.0
visibility:           public
id:                   aeson-1.5.6.0-9RfWlbr0iJzGkGGEmlWhlU
key:                  aeson-1.5.6.0-9RfWlbr0iJzGkGGEmlWhlU
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  3b999feb2ef2544e257c1c0c4f56bf98
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser
    Data.Aeson.Parser.Internal Data.Aeson.QQ.Simple Data.Aeson.TH
    Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Encoding.Builder Data.Aeson.Internal.Functions
    Data.Aeson.Parser.Unescape Data.Aeson.Parser.Time
    Data.Aeson.Types.FromJSON Data.Aeson.Types.Generic
    Data.Aeson.Types.ToJSON Data.Aeson.Types.Class
    Data.Aeson.Types.Internal Data.Attoparsec.Time
    Data.Attoparsec.Time.Internal Data.Aeson.Parser.UnescapePure

import-dirs:          /usr/lib/ghc-9.0.2/site-local/aeson-1.5.6.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/aeson-1.5.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson
hs-libraries:         HSaeson-1.5.6.0-9RfWlbr0iJzGkGGEmlWhlU
depends:
    attoparsec-0.14.4-G41f0gWdRBwHFZTIHlcTn0 base-4.15.1.0
    base-compat-batteries-0.12.1-Gp13J2MhViX598p1IOaouY
    bytestring-0.10.12.1 containers-0.6.4.1
    data-fix-0.3.2-JGV4eQaLj4FAXxzZQ35Q4z deepseq-1.4.5.0
    dlist-1.0-F00OxiD1dC249OyRKVGlo2 ghc-prim-0.7.0
    hashable-1.4.0.0-3tT111jpna6LV0O1fUcNNF
    primitive-0.7.3.0-HuG2rWCCHI33cxmpgTscxY
    scientific-0.3.7.0-E01AE3UMoe8CW5OmFZAQFW
    strict-0.4.0.1-JkKlEzqxyBeIwjRKtTesCD
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR template-haskell-2.17.0.0
    text-1.2.5.0 th-abstraction-0.4.3.0-KTsBdnGbxBE1GYg4VOLAou
    these-1.1.1.1-BUwx0f3eWbcJhF9Tsi2MuW time-1.9.3
    time-compat-1.9.6.1-44ggFP5QUlE7EMiYiSiSjC
    unordered-containers-0.2.17.0-4bcRecgfIOjL5KIXJoFyIi
    uuid-types-1.0.5-8rTNGPwVXQIEXYgM6AuKNT
    vector-0.12.3.1-K551lzEJJcR9600hgrx2VO

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-1.5.6.0-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson
version:              1.5.6.0
visibility:           public
id:                   aeson-1.5.6.0-ACA5il8oUDTGWSuengtGRp
key:                  aeson-1.5.6.0-ACA5il8oUDTGWSuengtGRp
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  31d5fa24f693f455f9200e68203be6de
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Encoding
    Data.Aeson.Encoding.Internal Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser
    Data.Aeson.Parser.Internal Data.Aeson.QQ.Simple Data.Aeson.TH
    Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Encoding.Builder Data.Aeson.Internal.Functions
    Data.Aeson.Parser.Unescape Data.Aeson.Parser.Time
    Data.Aeson.Types.FromJSON Data.Aeson.Types.Generic
    Data.Aeson.Types.ToJSON Data.Aeson.Types.Class
    Data.Aeson.Types.Internal Data.Attoparsec.Time
    Data.Attoparsec.Time.Internal Data.Aeson.Parser.UnescapePure

import-dirs:          /usr/lib/ghc-9.0.2/site-local/aeson-1.5.6.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/aeson-1.5.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson
hs-libraries:         HSaeson-1.5.6.0-ACA5il8oUDTGWSuengtGRp
depends:
    attoparsec-0.14.4-3hmNOn9KsQkLastvrl1LA3 base-4.15.1.0
    base-compat-batteries-0.12.1-8kdavVBlELw8bPnhTtjRzj
    bytestring-0.10.12.1 containers-0.6.4.1
    data-fix-0.3.2-GSIROTK8oHXCd6epfb6H46 deepseq-1.4.5.0
    dlist-1.0-F00OxiD1dC249OyRKVGlo2 ghc-prim-0.7.0
    hashable-1.4.0.0-Ad25gOPS1LBBwFTwmctznB
    primitive-0.7.3.0-8OGcgOY0vHCJaje3xtWYyl
    scientific-0.3.7.0-9vsr1QfQUPrAQX7lXehCHN
    strict-0.4.0.1-5GYm1x0KruB5sdJVm1v2i
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR template-haskell-2.17.0.0
    text-1.2.5.0 th-abstraction-0.4.3.0-KTsBdnGbxBE1GYg4VOLAou
    these-1.1.1.1-Len2udzwEil8OFbUUWRLNn time-1.9.3
    time-compat-1.9.6.1-JiAJgtOpM6r1TLWNDRWFV3
    unordered-containers-0.2.18.0-HgeMTnP7CmhGWtqS52RLit
    uuid-types-1.0.5-52RseRUZ19M6Jw2jxJxwG8
    vector-0.12.3.1-6ArAehJI8jX1p1vyTVOQhO

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
